==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/mn/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Бөөнөөр устгах активыг баталгаажуулна уу',
  'bulk_delete_help'	=> 'Доорхи их хэмжээний устгалт хийх хөрөнгийг хянаж үзэх. Устгагдсан тохиолдолд эдгээр хөрөнгийг сэргээж болно. Гэхдээ тэдгээр нь одоогоор тэдгээрт хуваарилагдсан хэрэглэгчдэд хамааралгүй болно.',
  'bulk_delete_warn'	=> 'Та устгах гэж байна: asset_count хөрөнгө.',
	'bulk_update'		=> 'Бөөнөөр шинэчлэх актив',
	'bulk_update_help'	=> 'Энэ маягтыг олон дахин нэг зэрэг олон актив шинэчлэх боломжтой. Зөвхөн өөрчлөх шаардлагатай талбаруудыг бөглөөрэй. Хоосон үлдсэн талбарууд өөрчлөгдөхгүй хэвээр үлдэнэ.',
	'bulk_update_warn'	=> 'Та asset_count активын шинж чанарыг засах гэж байна.',
    'checkedout_to'		=> 'Үүнийг шалгах',
    'checkout_date'		=> 'Тооцоо хийх өдөр',
    'checkin_date'		=> 'Checkin Огноо',
    'checkout_to'		=> 'Тооцоо хийх',
    'cost'				=> 'Худалдан авах зардал',
    'create'			=> 'Хөрөнгө үүсгэх',
    'date'				=> 'Худалдан авах өдөр',
    'depreciation'	    => 'Элэгдэл',
    'depreciates_on'	=> 'On',
    'default_location'	=> 'Анхдагч байршил',
    'eol_date'			=> 'EOL Огноо',
    'eol_rate'			=> 'EOL Rate',
    'expected_checkin'  => 'Хүлээгдэж буй хугацаа',
    'expires'			=> 'Хугацаа дуусна',
    'fully_depreciated'	=> 'Бүрэн тооцсон',
    'help_checkout'		=> 'Хэрэв та энэ хөрөнгийг нэн даруй олгохыг хүсвэл дээрх статусын жагсаалтаас "Илгээхэд бэлэн" -ийг сонгоно уу.',
    'mac_address'		=> 'MAC хаяг',
    'manufacturer'		=> 'Үйлдвэрлэгч',
    'model'				=> 'Загвар',
    'months'			=> 'сар',
    'name'				=> 'Хөрөнгийн нэр',
    'notes'				=> 'Тэмдэглэл',
    'order'				=> 'Захиалгын дугаар',
    'qr'				=> 'QR код',
    'requestable'		=> 'Хэрэглэгчид энэ хөрөнгийг шаардаж болно',
    'select_statustype'	=> 'Статусын төрлийг сонгоно уу',
    'serial'			=> 'Цуваа',
    'status'			=> 'Статус',
    'tag'				=> 'Хөрөнгийн шошго',
    'update'			=> 'Хөрөнгийн шинэчлэлт',
    'warranty'			=> 'Баталгаат',
		'warranty_expires'		=> 'Баталгаат хугацаа дуусах',
    'years'				=> 'жил',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/mn/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Бөөнөөр устгах активыг баталгаажуулна уу',
  'bulk_delete_help'	=> 'Доорхи их хэмжээний устгалт хийх хөрөнгийг хянаж үзэх. Устгагдсан тохиолдолд эдгээр хөрөнгийг сэргээж болно. Гэхдээ тэдгээр нь одоогоор тэдгээрт хуваарилагдсан хэрэглэгчдэд хамааралгүй болно.',
  'bulk_delete_warn'	=> 'Та устгах гэж байна: asset_count хөрөнгө.',
    'bulk_update'		=> 'Бөөнөөр шинэчлэх актив',
    'bulk_update_help'	=> 'Энэ маягтыг олон дахин нэг зэрэг олон актив шинэчлэх боломжтой. Зөвхөн өөрчлөх шаардлагатай талбаруудыг бөглөөрэй. Хоосон үлдсэн талбарууд өөрчлөгдөхгүй хэвээр үлдэнэ.',
    'bulk_update_warn'	=> 'Та asset_count активын шинж чанарыг засах гэж байна.',
    'checkedout_to'		=> 'Үүнийг шалгах',
    'checkout_date'		=> 'Тооцоо хийх өдөр',
    'checkin_date'		=> 'Checkin Огноо',
    'checkout_to'		=> 'Тооцоо хийх',
    'cost'				=> 'Худалдан авах зардал',
    'create'			=> 'Хөрөнгө үүсгэх',
    'date'				=> 'Худалдан авах өдөр',
    'depreciation'	    => 'Элэгдэл',
    'depreciates_on'	=> 'On',
    'default_location'	=> 'Анхдагч байршил',
    'eol_date'			=> 'EOL Огноо',
    'eol_rate'			=> 'EOL Rate',
    'expected_checkin'  => 'Хүлээгдэж буй хугацаа',
    'expires'			=> 'Хугацаа дуусна',
    'fully_depreciated'	=> 'Бүрэн тооцсон',
    'help_checkout'		=> 'Хэрэв та энэ хөрөнгийг нэн даруй олгохыг хүсвэл дээрх статусын жагсаалтаас "Илгээхэд бэлэн" -ийг сонгоно уу.',
    'mac_address'		=> 'MAC хаяг',
    'manufacturer'		=> 'Үйлдвэрлэгч',
    'model'				=> 'Загвар',
    'months'			=> 'сар',
    'name'				=> 'Хөрөнгийн нэр',
    'notes'				=> 'Тэмдэглэл',
    'order'				=> 'Захиалгын дугаар',
    'qr'				=> 'QR код',
    'requestable'		=> 'Хэрэглэгчид энэ хөрөнгийг шаардаж болно',
    'select_statustype'	=> 'Статусын төрлийг сонгоно уу',
    'serial'			=> 'Цуваа',
    'status'			=> 'Статус',
    'tag'				=> 'Хөрөнгийн шошго',
    'update'			=> 'Хөрөнгийн шинэчлэлт',
    'warranty'			=> 'Баталгаат',
        'warranty_expires'		=> 'Баталгаат хугацаа дуусах',
    'years'				=> 'жил',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
